@@ -9,6 +9,12 @@ if (package and package.preload and package.preload.TH) == nil then
   error "This file must be invoked by the CorsixTH executable"
 end
 
+-- Set a large enough cstacklimit to load complex saves in stack based
+-- versions of lua, such as 5.4.[01]
+if debug.setcstacklimit then
+  debug.setcstacklimit(30000)
+end
+
 -- Parse script parameters:
 local run_debugger = false
 for _, arg in ipairs({...}) do
@@ -82,7 +88,7 @@ end
 
 -- Check Lua version
 if _VERSION ~= "Lua 5.1" then
-  if _VERSION == "Lua 5.2" or _VERSION == "Lua 5.3" then
+  if _VERSION == "Lua 5.2" or _VERSION == "Lua 5.3" or _VERSION == "Lua 5.4" then
     -- Compatibility: Keep the global unpack function
     unpack = table.unpack
     -- Compatibility: Provide a replacement for deprecated ipairs()
