@@ -18,6 +18,10 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE. --]]
 
+corsixth.require("announcer")
+
+local AnnouncementPriority = _G["AnnouncementPriority"]
+
 class "CallsDispatcher"
 
 ---@type CallsDispatcher
@@ -61,7 +65,7 @@ function CallsDispatcher:callForStaff(room)
   end
   local sound = room.room_info.call_sound
   if anyone_missed and sound and not room.sound_played then
-    room.world.ui:playAnnouncement(sound)
+    room.world.ui:playAnnouncement(sound, AnnouncementPriority.Normal)
     room.sound_played = true
   end
 end
@@ -111,18 +115,12 @@ function CallsDispatcher:callForRepair(object, urgent, manual, lock_room)
   object:setRepairingMode(lock_room and true or false)
   local message
   local ui = object.world.ui
-  if not object.world:getLocalPlayerHospital():hasStaffOfCategory("Handyman") then
+  if object.world:getLocalPlayerHospital():countStaffOfCategory("Handyman", 1) == 0 then
     -- Advise about hiring Handyman
     message = _A.warnings.machinery_damaged2
   end
 
   if not manual and urgent then
-    local room = object:getRoom()
-    local sound = room.room_info.handyman_call_sound
-    if sound then
-      ui:playAnnouncement(sound)
-      ui:playSound("machwarn.wav")
-    end
     message = _A.warnings.machines_falling_apart
   end
   if message then
@@ -519,7 +517,7 @@ function CallsDispatcher.getPriorityForRoom(room, attribute, staff)
     end
   end
 
-  -- Prefer the tirer staff (such that less chance to have "resting sychronization issue")
+  -- Prefer the tirer staff (such that less chance to have "resting synchronization issue")
   score = score - staff.attributes["fatigue"] * 40 -- 40 is just a weighting scale
 
   -- TODO: Assign doctor with higher ability
