@@ -251,7 +251,7 @@ moods("cold",           3994,       0,       true) -- These have no priority sin
 moods("hot",            3988,       0,       true) -- they will be shown when hovering
 moods("queue",          4568,      70)             -- no matter what other priorities.
 moods("poo",            3996,       5)
-moods("sad_money",      4018,      50)
+moods("sad_money",      4018,      55)
 moods("patient_wait",   5006,      40)
 moods("epidemy1",       4566,      55)
 moods("epidemy2",       4570,      55)
@@ -492,8 +492,6 @@ local function Humanoid_startAction(self)
     elseif class.is(self, Staff) then
       ui:addWindow(UIStaff(ui, self))
     end
-    -- Pause the game.
-    self.world:setSpeed("Pause")
 
     -- Tell the player what just happened.
     self.world:gameLog("")
@@ -501,7 +499,7 @@ local function Humanoid_startAction(self)
     self.world:gameLog("Last action: " .. self.previous_action.name)
     self.world:gameLog(debug.traceback())
 
-    ui:addWindow(UIConfirmDialog(ui,
+    ui:addWindow(UIConfirmDialog(ui, true,
       "Sorry, a humanoid just had an empty action queue,"..
       " which means that he or she didn't know what to do next."..
       " Please consult the command window for more detailed information. "..
@@ -518,15 +516,8 @@ local function Humanoid_startAction(self)
           self.hospital = self.world:getLocalPlayerHospital()
           self:goHome("kicked")
         end
-        if TheApp.world:isCurrentSpeed("Pause") then
-          TheApp.world:setSpeed(TheApp.world.prev_speed)
-        end
       end,
-      --[[persistable:humanoid_stay_in_hospital]] function()
-        if TheApp.world:isCurrentSpeed("Pause") then
-          TheApp.world:setSpeed(TheApp.world.prev_speed)
-        end
-      end
+      nil -- Do nothing on cancel
     ))
     action = self.action_queue[1]
 
@@ -762,8 +753,8 @@ end
 -- Check if it is cold or hot around the humanoid and increase/decrease the
 -- feeling of warmth accordingly. Returns whether the calling function should proceed.
 function Humanoid:tickDay()
-  -- No use doing anything if we're going home
-  if self.going_home then
+  -- No use doing anything if we're going home/fired (or dead)
+  if self.going_home or self.dead then
     return false
   end
 
@@ -931,13 +922,14 @@ function Humanoid:tostring()
 
   local result = string.format("%s - class: %s", full_name, class)
 
-  result = result .. string.format("\nWarmth: %.3f   Happiness: %.3f   Fatigue: %.3f  Thirst: %.3f  Toilet_Need: %.3f   Health: %.3f",
+  result = result .. string.format("\nWarmth: %.3f   Happiness: %.3f   Fatigue: %.3f  Thirst: %.3f  Toilet_Need: %.3f   Health: %.3f   Service Quality: %.3f",
     self.attributes["warmth"] or 0,
     self.attributes["happiness"] or 0,
     self.attributes["fatigue"] or 0,
     self.attributes["thirst"] or 0,
     self.attributes["toilet_need"] or 0,
-    self.attributes["health"] or 0)
+    self.attributes["health"] or 0,
+    self.attributes["fatigue"] and self:getServiceQuality() or 0)
 
   result = result .. "\nActions: ["
   for i = 1, #self.action_queue do
@@ -988,4 +980,4 @@ function Humanoid:unexpectFromRoom(dest_room)
       dest_room.door:updateDynamicInfo()
     end
   end
- end
\ No newline at end of file
+ end
