@@ -269,7 +269,8 @@ epidemic was started to be fair on the players so they don't instantly fail.
 Additionally if any patients die during an epidemic we also remove them,
 otherwise a player may never win the epidemic in such a case.]]
 function Epidemic:checkPatientsForRemoval()
-  for i, infected_patient in ipairs(self.infected_patients) do
+  for i = #self.infected_patients, 1, -1 do
+    local infected_patient = self.infected_patients[i]
     if (not self.coverup_in_progress and infected_patient.going_home) or
         infected_patient.dead then
       table.remove(self.infected_patients,i)
@@ -389,6 +390,8 @@ function Epidemic:startCoverUp()
   self.timer = UIWatch(self.world.ui, "epidemic")
   self.countdown_intervals = self.timer.open_timer
   self.world.ui:addWindow(self.timer)
+  -- last chance clean up as entities might have ticked and changed state
+  self:checkPatientsForRemoval()
   self.coverup_in_progress = true
   --Set the mood icon for all infected patients
   for _, infected_patient in ipairs(self.infected_patients) do
@@ -544,7 +547,7 @@ end
   @param patient (Patient) the patient we wish to determine if they are static.]]
 local function is_static(patient)
   local action = patient:getCurrentAction()
-  return action.name == "queue" or action.name == "idle" or
+  return action.name == "queue" or action.name == "idle" or action.name == "seek_room" or
       (action.name == "use_object" and action.object.object_type.id == "bench")
 end
 
@@ -581,6 +584,7 @@ function Epidemic:createVaccinationActions(patient,nurse)
     patient:giveVaccinationCandidateStatus()
     local level_config = self.world.map.level_config
     local fee = level_config.gbv.VacCost or 50
+    nurse:setDynamicInfoText(_S.dynamic_info.staff.actions.vaccine)
     nurse:setNextAction(WalkAction(x, y):setMustHappen(true):enableWalkingToVaccinate())
     nurse:queueAction(VaccinateAction(patient, fee))
   end
