@@ -166,6 +166,9 @@ describe("Date", function()
     assert.False(date1 == date2)
     assert.True(date1 > date2)
     assert.False(date1 < date2)
+    assert.False(date1 < other_date1)
+    assert.True(date1 <= other_date1)
+    assert.False(date1 <= date2)
     assert.True(date1 >= other_date1)
     assert.False(date_with_different_hour == date1)
     assert.True(date_with_different_hour > date1)
