@@ -1295,7 +1295,7 @@ bool THAnimation_is_multiple_frame_animation(drawable* pSelf) {
 
 }  // namespace
 
-animation_base::animation_base() {
+animation_base::animation_base() : drawable() {
   x_relative_to_tile = 0;
   y_relative_to_tile = 0;
   for (int i = 0; i < 13; ++i) {
@@ -1305,7 +1305,8 @@ animation_base::animation_base() {
 }
 
 animation::animation()
-    : manager(nullptr),
+    : animation_base(),
+      manager(nullptr),
       morph_target(nullptr),
       animation_index(0),
       frame_index(0),
@@ -1449,7 +1450,7 @@ void animation::depersist(lua_persist_reader* pReader) {
       if (!pReader->read_int(speed.dy)) break;
     } else {
       if (!pReader->read_stack_object()) break;
-      parent = (animation*)lua_touserdata(L, -1);
+      parent = static_cast<animation*>(lua_touserdata(L, -1));
       lua_pop(L, 1);
     }
 
@@ -1469,7 +1470,7 @@ void animation::depersist(lua_persist_reader* pReader) {
 
     // Fix the m_pAnimator field
     luaT_getenvfield(L, 2, "animator");
-    manager = (animation_manager*)lua_touserdata(L, -1);
+    manager = static_cast<animation_manager*>(lua_touserdata(L, -1));
     lua_pop(L, 1);
 
     return;
@@ -1508,12 +1509,13 @@ void animation_base::attach_to_tile(map_tile* pMapNode, int layer) {
   if (flags & thdf_early_list) {
     pList = &pMapNode->oEarlyEntities;
   } else {
-    pList = pMapNode;
+    pList = &pMapNode->entities;
   }
 
   this->set_drawing_layer(layer);
 
-  while (pList->next && pList->next->get_drawing_layer() < layer) {
+  while (pList->next &&
+         static_cast<drawable*>(pList->next)->get_drawing_layer() < layer) {
     pList = pList->next;
   }
 
@@ -1692,7 +1694,7 @@ bool THSpriteRenderList_is_multiple_frame_animation(drawable* pSelf) {
 
 }  // namespace
 
-sprite_render_list::sprite_render_list() {
+sprite_render_list::sprite_render_list() : animation_base() {
   draw_fn = THSpriteRenderList_draw;
   hit_test_fn = THSpriteRenderList_hit_test;
   is_multiple_frame_animation_fn =
@@ -1859,6 +1861,6 @@ void sprite_render_list::depersist(lua_persist_reader* pReader) {
 
   // Fix the sheet field
   luaT_getenvfield(L, 2, "sheet");
-  sheet = (sprite_sheet*)lua_touserdata(L, -1);
+  sheet = static_cast<sprite_sheet*>(lua_touserdata(L, -1));
   lua_pop(L, 1);
 }
