@@ -213,6 +213,10 @@ int l_get_compile_options(lua_State* L) {
   }
   lua_setfield(L, -2, "jit");
 
+  // Report operating system
+  lua_pushliteral(L, CORSIX_TH_OS);
+  lua_setfield(L, -2, "os");
+
   lua_pushinteger(L, get_api_version());
   lua_setfield(L, -2, "api_version");
 
@@ -320,6 +324,24 @@ void luaT_pushtablebool(lua_State* L, const char* k, bool v) {
   lua_settable(L, -3);
 }
 
+void luaT_printvalue(lua_State* L, int idx) {
+  int t = lua_type(L, idx);
+  switch (t) {
+    case LUA_TSTRING: /* strings */
+      std::printf("string: '%s'\n", lua_tostring(L, idx));
+      break;
+    case LUA_TBOOLEAN: /* booleans */
+      std::printf("boolean %s\n", lua_toboolean(L, idx) ? "true" : "false");
+      break;
+    case LUA_TNUMBER: /* numbers */
+      std::printf("number: %g\n", lua_tonumber(L, idx));
+      break;
+    default: /* other values */
+      std::printf("%s: %p\n", lua_typename(L, t), lua_topointer(L, idx));
+      break;
+  }
+}
+
 void luaT_printstack(lua_State* L) {
   int i;
   int top = lua_gettop(L);
@@ -327,51 +349,22 @@ void luaT_printstack(lua_State* L) {
   std::printf("total items in stack %d\n", top);
 
   for (i = 1; i <= top; i++) { /* repeat for each level */
-    int t = lua_type(L, i);
-    switch (t) {
-      case LUA_TSTRING: /* strings */
-        std::printf("string: '%s'\n", lua_tostring(L, i));
-        break;
-      case LUA_TBOOLEAN: /* booleans */
-        std::printf("boolean %s\n", lua_toboolean(L, i) ? "true" : "false");
-        break;
-      case LUA_TNUMBER: /* numbers */
-        std::printf("number: %g\n", lua_tonumber(L, i));
-        break;
-      default: /* other values */
-        std::printf("%s\n", lua_typename(L, t));
-        break;
-    }
-    std::printf(" "); /* put a separator */
+    std::printf("(%d) ", i);
+    luaT_printvalue(L, i);
   }
   std::printf("\n"); /* end the listing */
 }
 
 void luaT_printrawtable(lua_State* L, int idx) {
-  int i;
-  int len = static_cast<int>(lua_objlen(L, idx));
-
-  std::printf("total items in table %d\n", len);
-
-  for (i = 1; i <= len; i++) {
-    lua_rawgeti(L, idx, i);
-    int t = lua_type(L, -1);
-    switch (t) {
-      case LUA_TSTRING: /* strings */
-        std::printf("string: '%s'\n", lua_tostring(L, -1));
-        break;
-      case LUA_TBOOLEAN: /* booleans */
-        std::printf("boolean %s\n", lua_toboolean(L, -1) ? "true" : "false");
-        break;
-      case LUA_TNUMBER: /* numbers */
-        std::printf("number: %g\n", lua_tonumber(L, -1));
-        break;
-      default: /* other values */
-        std::printf("%s\n", lua_typename(L, t));
-        break;
-    }
-    std::printf(" "); /* put a separator */
+  /* table is in the stack at index 't' */
+  lua_pushnil(L); /* first key */
+  while (lua_next(L, idx) != 0) {
+    /* uses 'key' (at index -2) and 'value' (at index -1) */
+    std::printf("key: ");
+    luaT_printvalue(L, -2);
+    std::printf("value: ");
+    luaT_printvalue(L, -1);
+    /* removes 'value'; keeps 'key' for next iteration */
     lua_pop(L, 1);
   }
-  std::printf("\n"); /* end the listing */
 }
