@@ -471,9 +471,7 @@ int l_layers_set(lua_State* L) {
 
 int l_layers_persist(lua_State* L) {
   layers* pLayers = luaT_testuserdata<layers>(L);
-  lua_settop(L, 2);
-  lua_insert(L, 1);
-  lua_persist_writer* pWriter = (lua_persist_writer*)lua_touserdata(L, 1);
+  lua_persist_writer* pWriter = (lua_persist_writer*)lua_touserdata(L, 2);
 
   int iNumLayers = 13;
   for (; iNumLayers >= 1; --iNumLayers) {
@@ -551,6 +549,7 @@ render_target_creation_params l_surface_creation_params(lua_State* L,
 
   oParams.fullscreen = false;
   oParams.present_immediate = false;
+  oParams.direct_zoom = false;
 
   // Parse string arguments, looking for matching parameter names.
   for (int iArg = iArgStart + 2, iArgCount = lua_gettop(L); iArg <= iArgCount;
@@ -558,9 +557,15 @@ render_target_creation_params l_surface_creation_params(lua_State* L,
     const char* sOption = luaL_checkstring(L, iArg);
     if (sOption[0] == 0) continue;
 
-    if (std::strcmp(sOption, "fullscreen") == 0) oParams.fullscreen = true;
-    if (std::strcmp(sOption, "present immediate") == 0)
+    if (std::strcmp(sOption, "fullscreen") == 0) {
+      oParams.fullscreen = true;
+    }
+    if (std::strcmp(sOption, "present immediate") == 0) {
       oParams.present_immediate = true;
+    }
+    if (std::strcmp(sOption, "direct zoom") == 0) {
+      oParams.direct_zoom = true;
+    }
   }
 
   return oParams;
@@ -798,9 +803,7 @@ int l_line_draw(lua_State* L) {
 
 int l_line_persist(lua_State* L) {
   line* pLine = luaT_testuserdata<line>(L);
-  lua_settop(L, 2);
-  lua_insert(L, 1);
-  lua_persist_writer* pWriter = (lua_persist_writer*)lua_touserdata(L, 1);
+  lua_persist_writer* pWriter = (lua_persist_writer*)lua_touserdata(L, 2);
   pLine->persist(pWriter);
   return 0;
 }
